Itsim project creation library
==============================

How to use
----------

```
pip install itsim_project_creation_library
```

Then in python
```
from itsim_project_creation_library import (
    feed_processing,
    gis_processing,
)
```

How to develop on it
--------------------

```
pip install -e .
```
